Enum pallet_committee::pallet::Error [−][src]
pub enum Error<T> {
Show 17 variants
NotMember,
DuplicateVote,
NotInVotingPeriod,
NotEligibileToVoteYet,
AlreadyCouncilMember,
AlreadyConstituentMember,
VotingPeriodNotElapsed,
ProposalNotAcceptedInsufficientVotes,
ProposalNotAcceptedConstituentVeto,
ProposalNotAcceptedCouncilDeny,
ProposalTimeout,
ProposalAlreadyExecuted,
MinimalCouncilMembers,
NoProposalWithHash,
ProposalNonceExhausted,
InvalidOperationInEndBlockComputation,
InvalidVotingPeriod,
// some variants omitted
}Expand description
Custom dispatch errors of this pallet.
Variants
The origin making the call is not a member and it is a requirement that they are
Member has attempted to vote multiple times on a single proposal
Attempted to cast a vote outside the accepted voting period for a proposal
Attempted to cast a vote without voting eligibility
Attempted to add a constituent that is already a member of the council
Attempted to add a constituent that is already a constituent
Attempted to close a proposal before the voting period is over
Tried to close a proposal but not enough council members voted
Tried to close a proposal but the constituent members voted to veto proposal
Tried to close a proposal but proposal was denied by council
Attempted to execute a proposal that is timeout
Attempted to execute a proposal that has already been executed
Reach the minimal number of the limit of council members
The hash provided does not have an associated proposal
The data type for enumerating the proposals has reached its upper bound. No more proposals can be made
There was a numerical overflow or underflow in calculating when the voting period should end
Attempted to set VotingPeriod out of the range of 7 days ~ 28 days
Implementations